# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/oauth/Client.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.media import MediaItem_pb2 as opencannabis_dot_media_dot_MediaItem__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2
from opencannabis.oauth import AuthorizationScope_pb2 as opencannabis_dot_oauth_dot_AuthorizationScope__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/oauth/Client.proto',
  package='opencannabis.oauth',
  syntax='proto3',
  serialized_options=b'\n\034io.opencannabis.schema.oauthB\013OAuthClientH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/oauth/Client.proto\x12\x12opencannabis.oauth\x1a\"opencannabis/media/MediaItem.proto\x1a#opencannabis/temporal/Instant.proto\x1a+opencannabis/oauth/AuthorizationScope.proto\"\xaa\x03\n\x06\x43lient\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontact\x18\x04 \x03(\t\x12\x32\n\x0bgrant_types\x18\x05 \x03(\x0e\x32\x1d.opencannabis.oauth.GrantType\x12/\n\x08\x62randing\x18\x06 \x01(\x0b\x32\x1d.opencannabis.media.MediaItem\x12\r\n\x05owner\x18\x07 \x01(\t\x12-\n\x06policy\x18\x08 \x01(\x0b\x32\x1d.opencannabis.media.MediaItem\x12,\n\x05terms\x18\t \x01(\x0b\x32\x1d.opencannabis.media.MediaItem\x12\x0e\n\x06public\x18\n \x01(\x08\x12\x14\n\x0credirect_uri\x18\x0b \x03(\t\x12\x37\n\rresponse_type\x18\x0c \x03(\x0e\x32 .opencannabis.oauth.ResponseType\x12\x35\n\x05scope\x18\r \x03(\x0b\x32&.opencannabis.oauth.AuthorizationScope\"\x8b\x01\n\x07\x43onsent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x32\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12\x14\n\x0credirect_uri\x18\x04 \x01(\t\x12\x17\n\x0frequested_scope\x18\x05 \x03(\t\"i\n\rConsentTicket\x12*\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x1a.opencannabis.oauth.Client\x12,\n\x07\x63onsent\x18\x02 \x01(\x0b\x32\x1b.opencannabis.oauth.Consent*P\n\x0cResponseType\x12\x1d\n\x19UNSPECIFIED_RESPONSE_TYPE\x10\x00\x12\t\n\x05TOKEN\x10\x01\x12\x08\n\x04\x43ODE\x10\x02\x12\x0c\n\x08ID_TOKEN\x10\x03*j\n\tGrantType\x12\x1a\n\x16UNSPECIFIED_GRANT_TYPE\x10\x00\x12\x16\n\x12\x41UTHORIZATION_CODE\x10\x01\x12\x11\n\rREFRESH_TOKEN\x10\x02\x12\x16\n\x12\x43LIENT_CREDENTIALS\x10\x03\x42\x35\n\x1cio.opencannabis.schema.oauthB\x0bOAuthClientH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_media_dot_MediaItem__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,opencannabis_dot_oauth_dot_AuthorizationScope__pb2.DESCRIPTOR,])

_RESPONSETYPE = _descriptor.EnumDescriptor(
  name='ResponseType',
  full_name='opencannabis.oauth.ResponseType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_RESPONSE_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOKEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CODE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ID_TOKEN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=851,
  serialized_end=931,
)
_sym_db.RegisterEnumDescriptor(_RESPONSETYPE)

ResponseType = enum_type_wrapper.EnumTypeWrapper(_RESPONSETYPE)
_GRANTTYPE = _descriptor.EnumDescriptor(
  name='GrantType',
  full_name='opencannabis.oauth.GrantType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_GRANT_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_CODE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REFRESH_TOKEN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_CREDENTIALS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=933,
  serialized_end=1039,
)
_sym_db.RegisterEnumDescriptor(_GRANTTYPE)

GrantType = enum_type_wrapper.EnumTypeWrapper(_GRANTTYPE)
UNSPECIFIED_RESPONSE_TYPE = 0
TOKEN = 1
CODE = 2
ID_TOKEN = 3
UNSPECIFIED_GRANT_TYPE = 0
AUTHORIZATION_CODE = 1
REFRESH_TOKEN = 2
CLIENT_CREDENTIALS = 3



_CLIENT = _descriptor.Descriptor(
  name='Client',
  full_name='opencannabis.oauth.Client',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.oauth.Client.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='opencannabis.oauth.Client.secret', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.oauth.Client.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contact', full_name='opencannabis.oauth.Client.contact', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grant_types', full_name='opencannabis.oauth.Client.grant_types', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branding', full_name='opencannabis.oauth.Client.branding', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='opencannabis.oauth.Client.owner', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policy', full_name='opencannabis.oauth.Client.policy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terms', full_name='opencannabis.oauth.Client.terms', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public', full_name='opencannabis.oauth.Client.public', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_uri', full_name='opencannabis.oauth.Client.redirect_uri', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_type', full_name='opencannabis.oauth.Client.response_type', index=11,
      number=12, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='opencannabis.oauth.Client.scope', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=600,
)


_CONSENT = _descriptor.Descriptor(
  name='Consent',
  full_name='opencannabis.oauth.Consent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.oauth.Consent.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='opencannabis.oauth.Consent.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='opencannabis.oauth.Consent.expires_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_uri', full_name='opencannabis.oauth.Consent.redirect_uri', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requested_scope', full_name='opencannabis.oauth.Consent.requested_scope', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=603,
  serialized_end=742,
)


_CONSENTTICKET = _descriptor.Descriptor(
  name='ConsentTicket',
  full_name='opencannabis.oauth.ConsentTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client', full_name='opencannabis.oauth.ConsentTicket.client', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consent', full_name='opencannabis.oauth.ConsentTicket.consent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=744,
  serialized_end=849,
)

_CLIENT.fields_by_name['grant_types'].enum_type = _GRANTTYPE
_CLIENT.fields_by_name['branding'].message_type = opencannabis_dot_media_dot_MediaItem__pb2._MEDIAITEM
_CLIENT.fields_by_name['policy'].message_type = opencannabis_dot_media_dot_MediaItem__pb2._MEDIAITEM
_CLIENT.fields_by_name['terms'].message_type = opencannabis_dot_media_dot_MediaItem__pb2._MEDIAITEM
_CLIENT.fields_by_name['response_type'].enum_type = _RESPONSETYPE
_CLIENT.fields_by_name['scope'].message_type = opencannabis_dot_oauth_dot_AuthorizationScope__pb2._AUTHORIZATIONSCOPE
_CONSENT.fields_by_name['expires_at'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_CONSENTTICKET.fields_by_name['client'].message_type = _CLIENT
_CONSENTTICKET.fields_by_name['consent'].message_type = _CONSENT
DESCRIPTOR.message_types_by_name['Client'] = _CLIENT
DESCRIPTOR.message_types_by_name['Consent'] = _CONSENT
DESCRIPTOR.message_types_by_name['ConsentTicket'] = _CONSENTTICKET
DESCRIPTOR.enum_types_by_name['ResponseType'] = _RESPONSETYPE
DESCRIPTOR.enum_types_by_name['GrantType'] = _GRANTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Client = _reflection.GeneratedProtocolMessageType('Client', (_message.Message,), {
  'DESCRIPTOR' : _CLIENT,
  '__module__' : 'opencannabis.oauth.Client_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.oauth.Client)
  })
_sym_db.RegisterMessage(Client)

Consent = _reflection.GeneratedProtocolMessageType('Consent', (_message.Message,), {
  'DESCRIPTOR' : _CONSENT,
  '__module__' : 'opencannabis.oauth.Client_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.oauth.Consent)
  })
_sym_db.RegisterMessage(Consent)

ConsentTicket = _reflection.GeneratedProtocolMessageType('ConsentTicket', (_message.Message,), {
  'DESCRIPTOR' : _CONSENTTICKET,
  '__module__' : 'opencannabis.oauth.Client_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.oauth.ConsentTicket)
  })
_sym_db.RegisterMessage(ConsentTicket)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/commerce/Item.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.structs.pricing import PricingDescriptor_pb2 as opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/commerce/Item.proto',
  package='opencannabis.commerce',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.commerceB\tOrderItemH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n opencannabis/commerce/Item.proto\x12\x15opencannabis.commerce\x1a\"opencannabis/base/ProductKey.proto\x1a\x34opencannabis/structs/pricing/PricingDescriptor.proto\"\xb1\x01\n\x0bVariantSpec\x12\x36\n\x07variant\x18\x01 \x01(\x0e\x32%.opencannabis.commerce.ProductVariant\x12\x41\n\x06weight\x18\x02 \x01(\x0e\x32/.opencannabis.structs.pricing.PricingWeightTierH\x00\x12\x0e\n\x04size\x18\x03 \x01(\tH\x00\x12\x0f\n\x05\x63olor\x18\x04 \x01(\tH\x00\x42\x06\n\x04spec\"\x96\x01\n\x04Item\x12*\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKey\x12\x33\n\x07variant\x18\x02 \x03(\x0b\x32\".opencannabis.commerce.VariantSpec\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x11\n\timage_uri\x18\x05 \x01(\t*1\n\x0eProductVariant\x12\n\n\x06WEIGHT\x10\x00\x12\t\n\x05\x43OLOR\x10\x01\x12\x08\n\x04SIZE\x10\x02\x42\x36\n\x1fio.opencannabis.schema.commerceB\tOrderItemH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2.DESCRIPTOR,])

_PRODUCTVARIANT = _descriptor.EnumDescriptor(
  name='ProductVariant',
  full_name='opencannabis.commerce.ProductVariant',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WEIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLOR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIZE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=482,
  serialized_end=531,
)
_sym_db.RegisterEnumDescriptor(_PRODUCTVARIANT)

ProductVariant = enum_type_wrapper.EnumTypeWrapper(_PRODUCTVARIANT)
WEIGHT = 0
COLOR = 1
SIZE = 2



_VARIANTSPEC = _descriptor.Descriptor(
  name='VariantSpec',
  full_name='opencannabis.commerce.VariantSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variant', full_name='opencannabis.commerce.VariantSpec.variant', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='opencannabis.commerce.VariantSpec.weight', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='opencannabis.commerce.VariantSpec.size', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='opencannabis.commerce.VariantSpec.color', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.commerce.VariantSpec.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=150,
  serialized_end=327,
)


_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='opencannabis.commerce.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.commerce.Item.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variant', full_name='opencannabis.commerce.Item.variant', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='opencannabis.commerce.Item.count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='opencannabis.commerce.Item.uri', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_uri', full_name='opencannabis.commerce.Item.image_uri', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=480,
)

_VARIANTSPEC.fields_by_name['variant'].enum_type = _PRODUCTVARIANT
_VARIANTSPEC.fields_by_name['weight'].enum_type = opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2._PRICINGWEIGHTTIER
_VARIANTSPEC.oneofs_by_name['spec'].fields.append(
  _VARIANTSPEC.fields_by_name['weight'])
_VARIANTSPEC.fields_by_name['weight'].containing_oneof = _VARIANTSPEC.oneofs_by_name['spec']
_VARIANTSPEC.oneofs_by_name['spec'].fields.append(
  _VARIANTSPEC.fields_by_name['size'])
_VARIANTSPEC.fields_by_name['size'].containing_oneof = _VARIANTSPEC.oneofs_by_name['spec']
_VARIANTSPEC.oneofs_by_name['spec'].fields.append(
  _VARIANTSPEC.fields_by_name['color'])
_VARIANTSPEC.fields_by_name['color'].containing_oneof = _VARIANTSPEC.oneofs_by_name['spec']
_ITEM.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_ITEM.fields_by_name['variant'].message_type = _VARIANTSPEC
DESCRIPTOR.message_types_by_name['VariantSpec'] = _VARIANTSPEC
DESCRIPTOR.message_types_by_name['Item'] = _ITEM
DESCRIPTOR.enum_types_by_name['ProductVariant'] = _PRODUCTVARIANT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VariantSpec = _reflection.GeneratedProtocolMessageType('VariantSpec', (_message.Message,), {
  'DESCRIPTOR' : _VARIANTSPEC,
  '__module__' : 'opencannabis.commerce.Item_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.VariantSpec)
  })
_sym_db.RegisterMessage(VariantSpec)

Item = _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), {
  'DESCRIPTOR' : _ITEM,
  '__module__' : 'opencannabis.commerce.Item_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.Item)
  })
_sym_db.RegisterMessage(Item)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.products.distribution`
  -------------------------------------
  Objects that describe and govern how products are distributed.

"""

# `opencannabis.products.distribution`



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/commerce/Order.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.commerce import Item_pb2 as opencannabis_dot_commerce_dot_Item__pb2
from opencannabis.commerce import Delivery_pb2 as opencannabis_dot_commerce_dot_Delivery__pb2
from opencannabis.commerce import Customer_pb2 as opencannabis_dot_commerce_dot_Customer__pb2
from opencannabis.commerce.payments import Payment_pb2 as opencannabis_dot_commerce_dot_payments_dot_Payment__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/commerce/Order.proto',
  package='opencannabis.commerce',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.commerceB\017CommercialOrderH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!opencannabis/commerce/Order.proto\x12\x15opencannabis.commerce\x1a\x19gust/core/datamodel.proto\x1a opencannabis/commerce/Item.proto\x1a$opencannabis/commerce/Delivery.proto\x1a$opencannabis/commerce/Customer.proto\x1a,opencannabis/commerce/payments/Payment.proto\x1a#opencannabis/temporal/Instant.proto\"\xec\x01\n\x0fOrderScheduling\x12w\n\nscheduling\x18\x01 \x01(\x0e\x32%.opencannabis.commerce.SchedulingTypeB<\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x32\x12\x30Scheduling type, either \'ASAP\' or a target time.\x12`\n\x0c\x64\x65sired_time\x18\x02 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantB*\xc2\xb5\x03&\x12$Desired delivery time, if specified.\"\xce\x02\n\x0cOrderPayment\x12]\n\x06status\x18\x01 \x01(\x0e\x32$.opencannabis.commerce.PaymentStatusB\'\xc2\xb5\x03#\x12!Status of payment for this order.\x12\x61\n\x06method\x18\x02 \x01(\x0e\x32$.opencannabis.commerce.PaymentMethodB+\xc2\xb5\x03\'\x12%Method of payment used on this order.\x12\x37\n\x03tax\x18\x03 \x01(\x01\x42*\xc2\xb5\x03&\x12$Amount of tax added to the subtotal.\x12\x43\n\x04paid\x18\x04 \x01(\x01\x42\x35\xc2\xb5\x03\x31\x12/Amount the user has paid so far for this order.\"\x85\x01\n\rStatusCheckin\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".opencannabis.commerce.OrderStatus\x12/\n\x07instant\x18\x02 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12\x0f\n\x07message\x18\x03 \x01(\t\"M\n\x08OrderKey\x12\x41\n\x02id\x18\x01 \x01(\tB5\xc2\xb5\x03\x31\x12/Order ID, assigned by the server upon creation.\"\xf0\x08\n\x05Order\x12h\n\x02id\x18\x01 \x01(\tB\\\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03R\x12PID assigned to the order by the server, and potentially nominated by the client.\x12p\n\x04type\x18\x02 \x01(\x0e\x32 .opencannabis.commerce.OrderTypeB@\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x36\x12\x34Type of order requested - either PICKUP or DELIVERY.\x12:\n\x06status\x18\x03 \x01(\x0e\x32\".opencannabis.commerce.OrderStatusB\x06\xca\xb5\x03\x02\x10\x01\x12\x62\n\x08\x63ustomer\x18\x04 \x01(\x0b\x32\x1f.opencannabis.commerce.CustomerB/\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03%\x12#Customer that submitted this order.\x12g\n\nscheduling\x18\x05 \x01(\x0b\x32&.opencannabis.commerce.OrderSchedulingB+\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03!\x12\x1fScheduling spec for this order.\x12l\n\x0b\x64\x65stination\x18\x06 \x01(\x0b\x32*.opencannabis.commerce.DeliveryDestinationB+\xc2\xb5\x03\'\x12%Location for delivery, if applicable.\x12\x15\n\x05notes\x18\x07 \x01(\tB\x06\xca\xb5\x03\x02\x10\x01\x12\x31\n\x04item\x18\x08 \x03(\x0b\x32\x1b.opencannabis.commerce.ItemB\x06\xca\xb5\x03\x02\x10\x01\x12@\n\naction_log\x18\t \x03(\x0b\x32$.opencannabis.commerce.StatusCheckinB\x06\xca\xb5\x03\x02\x10\x01\x12\\\n\ncreated_at\x18\n \x01(\x0b\x32\x1e.opencannabis.temporal.InstantB(\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x1e\x12\x1cWhen this order was created.\x12\'\n\x08subtotal\x18\x0b \x01(\x01\x42\x15\xc2\xb5\x03\x11\x12\x0fOrder subtotal.\x12:\n\nupdated_at\x18\x0c \x01(\x0b\x32\x1e.opencannabis.temporal.InstantB\x06\xca\xb5\x03\x02\x10\x01\x12L\n\x03sid\x18\r \x01(\tB?\xc2\xb5\x03;\x12\x39Session ID that was active when this order was submitted.\x12w\n\x07payment\x18\x0e \x01(\x0b\x32#.opencannabis.commerce.OrderPaymentBA\xc2\xb5\x03=\x12;Payment information/metadata for this order, if applicable.*1\n\tOrderType\x12\n\n\x06PICKUP\x10\x00\x12\x0c\n\x08\x44\x45LIVERY\x10\x01\x12\n\n\x06ONSITE\x10\x02*%\n\x0eSchedulingType\x12\x08\n\x04\x41SAP\x10\x00\x12\t\n\x05TIMED\x10\x01*a\n\x0bOrderStatus\x12\x0b\n\x07PENDING\x10\x00\x12\x0c\n\x08\x41PPROVED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02\x12\x0c\n\x08\x41SSIGNED\x10\x03\x12\x0c\n\x08\x45N_ROUTE\x10\x04\x12\r\n\tFULFILLED\x10\x05\x42<\n\x1fio.opencannabis.schema.commerceB\x0f\x43ommercialOrderH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_commerce_dot_Item__pb2.DESCRIPTOR,opencannabis_dot_commerce_dot_Delivery__pb2.DESCRIPTOR,opencannabis_dot_commerce_dot_Customer__pb2.DESCRIPTOR,opencannabis_dot_commerce_dot_payments_dot_Payment__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,])

_ORDERTYPE = _descriptor.EnumDescriptor(
  name='OrderType',
  full_name='opencannabis.commerce.OrderType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PICKUP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELIVERY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONSITE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2210,
  serialized_end=2259,
)
_sym_db.RegisterEnumDescriptor(_ORDERTYPE)

OrderType = enum_type_wrapper.EnumTypeWrapper(_ORDERTYPE)
_SCHEDULINGTYPE = _descriptor.EnumDescriptor(
  name='SchedulingType',
  full_name='opencannabis.commerce.SchedulingType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ASAP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2261,
  serialized_end=2298,
)
_sym_db.RegisterEnumDescriptor(_SCHEDULINGTYPE)

SchedulingType = enum_type_wrapper.EnumTypeWrapper(_SCHEDULINGTYPE)
_ORDERSTATUS = _descriptor.EnumDescriptor(
  name='OrderStatus',
  full_name='opencannabis.commerce.OrderStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPROVED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REJECTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASSIGNED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EN_ROUTE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FULFILLED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2300,
  serialized_end=2397,
)
_sym_db.RegisterEnumDescriptor(_ORDERSTATUS)

OrderStatus = enum_type_wrapper.EnumTypeWrapper(_ORDERSTATUS)
PICKUP = 0
DELIVERY = 1
ONSITE = 2
ASAP = 0
TIMED = 1
PENDING = 0
APPROVED = 1
REJECTED = 2
ASSIGNED = 3
EN_ROUTE = 4
FULFILLED = 5



_ORDERSCHEDULING = _descriptor.Descriptor(
  name='OrderScheduling',
  full_name='opencannabis.commerce.OrderScheduling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scheduling', full_name='opencannabis.commerce.OrderScheduling.scheduling', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\0032\0220Scheduling type, either \'ASAP\' or a target time.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_time', full_name='opencannabis.commerce.OrderScheduling.desired_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003&\022$Desired delivery time, if specified.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=517,
)


_ORDERPAYMENT = _descriptor.Descriptor(
  name='OrderPayment',
  full_name='opencannabis.commerce.OrderPayment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='opencannabis.commerce.OrderPayment.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003#\022!Status of payment for this order.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='opencannabis.commerce.OrderPayment.method', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\'\022%Method of payment used on this order.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tax', full_name='opencannabis.commerce.OrderPayment.tax', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003&\022$Amount of tax added to the subtotal.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paid', full_name='opencannabis.commerce.OrderPayment.paid', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Amount the user has paid so far for this order.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=854,
)


_STATUSCHECKIN = _descriptor.Descriptor(
  name='StatusCheckin',
  full_name='opencannabis.commerce.StatusCheckin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='opencannabis.commerce.StatusCheckin.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instant', full_name='opencannabis.commerce.StatusCheckin.instant', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='opencannabis.commerce.StatusCheckin.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=990,
)


_ORDERKEY = _descriptor.Descriptor(
  name='OrderKey',
  full_name='opencannabis.commerce.OrderKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.commerce.OrderKey.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Order ID, assigned by the server upon creation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=992,
  serialized_end=1069,
)


_ORDER = _descriptor.Descriptor(
  name='Order',
  full_name='opencannabis.commerce.Order',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.commerce.Order.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003R\022PID assigned to the order by the server, and potentially nominated by the client.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.commerce.Order.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\0036\0224Type of order requested - either PICKUP or DELIVERY.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='opencannabis.commerce.Order.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer', full_name='opencannabis.commerce.Order.customer', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003%\022#Customer that submitted this order.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheduling', full_name='opencannabis.commerce.Order.scheduling', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003!\022\037Scheduling spec for this order.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination', full_name='opencannabis.commerce.Order.destination', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\'\022%Location for delivery, if applicable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notes', full_name='opencannabis.commerce.Order.notes', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item', full_name='opencannabis.commerce.Order.item', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action_log', full_name='opencannabis.commerce.Order.action_log', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='opencannabis.commerce.Order.created_at', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003\036\022\034When this order was created.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subtotal', full_name='opencannabis.commerce.Order.subtotal', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\021\022\017Order subtotal.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='opencannabis.commerce.Order.updated_at', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sid', full_name='opencannabis.commerce.Order.sid', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003;\0229Session ID that was active when this order was submitted.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment', full_name='opencannabis.commerce.Order.payment', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003=\022;Payment information/metadata for this order, if applicable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1072,
  serialized_end=2208,
)

_ORDERSCHEDULING.fields_by_name['scheduling'].enum_type = _SCHEDULINGTYPE
_ORDERSCHEDULING.fields_by_name['desired_time'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_ORDERPAYMENT.fields_by_name['status'].enum_type = opencannabis_dot_commerce_dot_payments_dot_Payment__pb2._PAYMENTSTATUS
_ORDERPAYMENT.fields_by_name['method'].enum_type = opencannabis_dot_commerce_dot_payments_dot_Payment__pb2._PAYMENTMETHOD
_STATUSCHECKIN.fields_by_name['status'].enum_type = _ORDERSTATUS
_STATUSCHECKIN.fields_by_name['instant'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_ORDER.fields_by_name['type'].enum_type = _ORDERTYPE
_ORDER.fields_by_name['status'].enum_type = _ORDERSTATUS
_ORDER.fields_by_name['customer'].message_type = opencannabis_dot_commerce_dot_Customer__pb2._CUSTOMER
_ORDER.fields_by_name['scheduling'].message_type = _ORDERSCHEDULING
_ORDER.fields_by_name['destination'].message_type = opencannabis_dot_commerce_dot_Delivery__pb2._DELIVERYDESTINATION
_ORDER.fields_by_name['item'].message_type = opencannabis_dot_commerce_dot_Item__pb2._ITEM
_ORDER.fields_by_name['action_log'].message_type = _STATUSCHECKIN
_ORDER.fields_by_name['created_at'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_ORDER.fields_by_name['updated_at'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_ORDER.fields_by_name['payment'].message_type = _ORDERPAYMENT
DESCRIPTOR.message_types_by_name['OrderScheduling'] = _ORDERSCHEDULING
DESCRIPTOR.message_types_by_name['OrderPayment'] = _ORDERPAYMENT
DESCRIPTOR.message_types_by_name['StatusCheckin'] = _STATUSCHECKIN
DESCRIPTOR.message_types_by_name['OrderKey'] = _ORDERKEY
DESCRIPTOR.message_types_by_name['Order'] = _ORDER
DESCRIPTOR.enum_types_by_name['OrderType'] = _ORDERTYPE
DESCRIPTOR.enum_types_by_name['SchedulingType'] = _SCHEDULINGTYPE
DESCRIPTOR.enum_types_by_name['OrderStatus'] = _ORDERSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OrderScheduling = _reflection.GeneratedProtocolMessageType('OrderScheduling', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSCHEDULING,
  '__module__' : 'opencannabis.commerce.Order_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.OrderScheduling)
  })
_sym_db.RegisterMessage(OrderScheduling)

OrderPayment = _reflection.GeneratedProtocolMessageType('OrderPayment', (_message.Message,), {
  'DESCRIPTOR' : _ORDERPAYMENT,
  '__module__' : 'opencannabis.commerce.Order_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.OrderPayment)
  })
_sym_db.RegisterMessage(OrderPayment)

StatusCheckin = _reflection.GeneratedProtocolMessageType('StatusCheckin', (_message.Message,), {
  'DESCRIPTOR' : _STATUSCHECKIN,
  '__module__' : 'opencannabis.commerce.Order_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.StatusCheckin)
  })
_sym_db.RegisterMessage(StatusCheckin)

OrderKey = _reflection.GeneratedProtocolMessageType('OrderKey', (_message.Message,), {
  'DESCRIPTOR' : _ORDERKEY,
  '__module__' : 'opencannabis.commerce.Order_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.OrderKey)
  })
_sym_db.RegisterMessage(OrderKey)

Order = _reflection.GeneratedProtocolMessageType('Order', (_message.Message,), {
  'DESCRIPTOR' : _ORDER,
  '__module__' : 'opencannabis.commerce.Order_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.Order)
  })
_sym_db.RegisterMessage(Order)


DESCRIPTOR._options = None
_ORDERSCHEDULING.fields_by_name['scheduling']._options = None
_ORDERSCHEDULING.fields_by_name['desired_time']._options = None
_ORDERPAYMENT.fields_by_name['status']._options = None
_ORDERPAYMENT.fields_by_name['method']._options = None
_ORDERPAYMENT.fields_by_name['tax']._options = None
_ORDERPAYMENT.fields_by_name['paid']._options = None
_ORDERKEY.fields_by_name['id']._options = None
_ORDER.fields_by_name['id']._options = None
_ORDER.fields_by_name['type']._options = None
_ORDER.fields_by_name['status']._options = None
_ORDER.fields_by_name['customer']._options = None
_ORDER.fields_by_name['scheduling']._options = None
_ORDER.fields_by_name['destination']._options = None
_ORDER.fields_by_name['notes']._options = None
_ORDER.fields_by_name['item']._options = None
_ORDER.fields_by_name['action_log']._options = None
_ORDER.fields_by_name['created_at']._options = None
_ORDER.fields_by_name['subtotal']._options = None
_ORDER.fields_by_name['updated_at']._options = None
_ORDER.fields_by_name['sid']._options = None
_ORDER.fields_by_name['payment']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/crypto/primitives/Integrity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/crypto/primitives/Integrity.proto',
  package='opencannabis.crypto',
  syntax='proto3',
  serialized_options=b'\n2io.opencannabis.schema.crypto.primitives.integrityH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.opencannabis/crypto/primitives/Integrity.proto\x12\x13opencannabis.crypto\"t\n\x04Hash\x12\x35\n\talgorithm\x18\x01 \x01(\x0e\x32\".opencannabis.crypto.HashAlgorithm\x12\r\n\x03raw\x18\x02 \x01(\x0cH\x00\x12\r\n\x03hex\x18\x03 \x01(\tH\x00\x12\r\n\x03\x62\x36\x34\x18\x04 \x01(\tH\x00\x42\x08\n\x06\x64igest\"C\n\nHashedData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\'\n\x04hash\x18\x02 \x01(\x0b\x32\x19.opencannabis.crypto.Hash*R\n\rHashAlgorithm\x12\x08\n\x04SHA1\x10\x00\x12\x07\n\x03MD5\x10\x01\x12\n\n\x06SHA256\x10\x02\x12\n\n\x06SHA384\x10\x03\x12\n\n\x06SHA512\x10\x04\x12\n\n\x06MURMUR\x10\x06\x42>\n2io.opencannabis.schema.crypto.primitives.integrityH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)

_HASHALGORITHM = _descriptor.EnumDescriptor(
  name='HashAlgorithm',
  full_name='opencannabis.crypto.HashAlgorithm',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHA1', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MD5', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA256', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA384', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA512', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MURMUR', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=258,
  serialized_end=340,
)
_sym_db.RegisterEnumDescriptor(_HASHALGORITHM)

HashAlgorithm = enum_type_wrapper.EnumTypeWrapper(_HASHALGORITHM)
SHA1 = 0
MD5 = 1
SHA256 = 2
SHA384 = 3
SHA512 = 4
MURMUR = 6



_HASH = _descriptor.Descriptor(
  name='Hash',
  full_name='opencannabis.crypto.Hash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='opencannabis.crypto.Hash.algorithm', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw', full_name='opencannabis.crypto.Hash.raw', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hex', full_name='opencannabis.crypto.Hash.hex', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b64', full_name='opencannabis.crypto.Hash.b64', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='digest', full_name='opencannabis.crypto.Hash.digest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=71,
  serialized_end=187,
)


_HASHEDDATA = _descriptor.Descriptor(
  name='HashedData',
  full_name='opencannabis.crypto.HashedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='opencannabis.crypto.HashedData.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash', full_name='opencannabis.crypto.HashedData.hash', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=256,
)

_HASH.fields_by_name['algorithm'].enum_type = _HASHALGORITHM
_HASH.oneofs_by_name['digest'].fields.append(
  _HASH.fields_by_name['raw'])
_HASH.fields_by_name['raw'].containing_oneof = _HASH.oneofs_by_name['digest']
_HASH.oneofs_by_name['digest'].fields.append(
  _HASH.fields_by_name['hex'])
_HASH.fields_by_name['hex'].containing_oneof = _HASH.oneofs_by_name['digest']
_HASH.oneofs_by_name['digest'].fields.append(
  _HASH.fields_by_name['b64'])
_HASH.fields_by_name['b64'].containing_oneof = _HASH.oneofs_by_name['digest']
_HASHEDDATA.fields_by_name['hash'].message_type = _HASH
DESCRIPTOR.message_types_by_name['Hash'] = _HASH
DESCRIPTOR.message_types_by_name['HashedData'] = _HASHEDDATA
DESCRIPTOR.enum_types_by_name['HashAlgorithm'] = _HASHALGORITHM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Hash = _reflection.GeneratedProtocolMessageType('Hash', (_message.Message,), {
  'DESCRIPTOR' : _HASH,
  '__module__' : 'opencannabis.crypto.primitives.Integrity_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.Hash)
  })
_sym_db.RegisterMessage(Hash)

HashedData = _reflection.GeneratedProtocolMessageType('HashedData', (_message.Message,), {
  'DESCRIPTOR' : _HASHEDDATA,
  '__module__' : 'opencannabis.crypto.primitives.Integrity_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.HashedData)
  })
_sym_db.RegisterMessage(HashedData)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/commerce/payments/Payment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/commerce/payments/Payment.proto',
  package='opencannabis.commerce',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.commerceB\010PaymentsH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,opencannabis/commerce/payments/Payment.proto\x12\x15opencannabis.commerce*k\n\rPaymentMethod\x12\x08\n\x04\x43\x41SH\x10\x00\x12\t\n\x05\x43HECK\x10\x01\x12\t\n\x05\x44\x45\x42IT\x10\x02\x12\n\n\x06\x43REDIT\x10\x03\x12\x0b\n\x07\x44IGITAL\x10\x04\x12\x07\n\x03\x41\x43H\x10\x05\x12\x08\n\x04WIRE\x10\x06\x12\x0e\n\nBLOCKCHAIN\x10\x07*s\n\x0fPaymentCardType\x12\x10\n\x0cNO_CARD_TYPE\x10\x00\x12\x08\n\x04VISA\x10\x01\x12\x0e\n\nMASTERCARD\x10\x02\x12\x0c\n\x08\x44ISCOVER\x10\x03\x12\x08\n\x04\x41MEX\x10\x04\x12\x0f\n\x0b\x44INERS_CLUB\x10\x05\x12\x0b\n\x07MAESTRO\x10\x06*S\n\x15\x44igitalPaymentNetwork\x12\x17\n\x13UNSPECIFIED_NETWORK\x10\x00\x12\n\n\x06PAYPAL\x10\x01\x12\t\n\x05VENMO\x10\x02\x12\n\n\x06SQUARE\x10\x03*]\n\rPaymentStatus\x12\x12\n\x0eNOT_APPLICABLE\x10\x00\x12\x0b\n\x07WAITING\x10\x01\x12\x11\n\rPREAUTHORIZED\x10\x02\x12\x0b\n\x07\x42OUNCED\x10\x03\x12\x0b\n\x07RETRIED\x10\x04*4\n\nBillStatus\x12\x0c\n\x08SUSPENSE\x10\x00\x12\x0b\n\x07PARTIAL\x10\x03\x12\x0b\n\x07SETTLED\x10\x04\x42\x35\n\x1fio.opencannabis.schema.commerceB\x08PaymentsH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)

_PAYMENTMETHOD = _descriptor.EnumDescriptor(
  name='PaymentMethod',
  full_name='opencannabis.commerce.PaymentMethod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CASH', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHECK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEBIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREDIT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIGITAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACH', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIRE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLOCKCHAIN', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=71,
  serialized_end=178,
)
_sym_db.RegisterEnumDescriptor(_PAYMENTMETHOD)

PaymentMethod = enum_type_wrapper.EnumTypeWrapper(_PAYMENTMETHOD)
_PAYMENTCARDTYPE = _descriptor.EnumDescriptor(
  name='PaymentCardType',
  full_name='opencannabis.commerce.PaymentCardType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_CARD_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VISA', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MASTERCARD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISCOVER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AMEX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DINERS_CLUB', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAESTRO', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=180,
  serialized_end=295,
)
_sym_db.RegisterEnumDescriptor(_PAYMENTCARDTYPE)

PaymentCardType = enum_type_wrapper.EnumTypeWrapper(_PAYMENTCARDTYPE)
_DIGITALPAYMENTNETWORK = _descriptor.EnumDescriptor(
  name='DigitalPaymentNetwork',
  full_name='opencannabis.commerce.DigitalPaymentNetwork',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_NETWORK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYPAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VENMO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SQUARE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=297,
  serialized_end=380,
)
_sym_db.RegisterEnumDescriptor(_DIGITALPAYMENTNETWORK)

DigitalPaymentNetwork = enum_type_wrapper.EnumTypeWrapper(_DIGITALPAYMENTNETWORK)
_PAYMENTSTATUS = _descriptor.EnumDescriptor(
  name='PaymentStatus',
  full_name='opencannabis.commerce.PaymentStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_APPLICABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAITING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREAUTHORIZED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOUNCED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RETRIED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=382,
  serialized_end=475,
)
_sym_db.RegisterEnumDescriptor(_PAYMENTSTATUS)

PaymentStatus = enum_type_wrapper.EnumTypeWrapper(_PAYMENTSTATUS)
_BILLSTATUS = _descriptor.EnumDescriptor(
  name='BillStatus',
  full_name='opencannabis.commerce.BillStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUSPENSE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTIAL', index=1, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SETTLED', index=2, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=477,
  serialized_end=529,
)
_sym_db.RegisterEnumDescriptor(_BILLSTATUS)

BillStatus = enum_type_wrapper.EnumTypeWrapper(_BILLSTATUS)
CASH = 0
CHECK = 1
DEBIT = 2
CREDIT = 3
DIGITAL = 4
ACH = 5
WIRE = 6
BLOCKCHAIN = 7
NO_CARD_TYPE = 0
VISA = 1
MASTERCARD = 2
DISCOVER = 3
AMEX = 4
DINERS_CLUB = 5
MAESTRO = 6
UNSPECIFIED_NETWORK = 0
PAYPAL = 1
VENMO = 2
SQUARE = 3
NOT_APPLICABLE = 0
WAITING = 1
PREAUTHORIZED = 2
BOUNCED = 3
RETRIED = 4
SUSPENSE = 0
PARTIAL = 3
SETTLED = 4


DESCRIPTOR.enum_types_by_name['PaymentMethod'] = _PAYMENTMETHOD
DESCRIPTOR.enum_types_by_name['PaymentCardType'] = _PAYMENTCARDTYPE
DESCRIPTOR.enum_types_by_name['DigitalPaymentNetwork'] = _DIGITALPAYMENTNETWORK
DESCRIPTOR.enum_types_by_name['PaymentStatus'] = _PAYMENTSTATUS
DESCRIPTOR.enum_types_by_name['BillStatus'] = _BILLSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/Edible.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.content import MaterialsData_pb2 as opencannabis_dot_content_dot_MaterialsData__pb2
from opencannabis.content import ProductContent_pb2 as opencannabis_dot_content_dot_ProductContent__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/Edible.proto',
  package='opencannabis.products',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.productB\rEdibleProductH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/products/Edible.proto\x12\x15opencannabis.products\x1a\"opencannabis/base/ProductKey.proto\x1a(opencannabis/content/MaterialsData.proto\x1a)opencannabis/content/ProductContent.proto\"1\n\x10\x45\x64ibleIngredient\x12\r\n\x05label\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"\xe5\x04\n\x06\x45\x64ible\x12*\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKey\x12\x30\n\x04type\x18\x02 \x01(\x0e\x32\".opencannabis.products.Edible.Type\x12\x31\n\x05\x66lags\x18\x03 \x03(\x0e\x32\".opencannabis.products.Edible.Flag\x12\x35\n\x07product\x18\x04 \x01(\x0b\x32$.opencannabis.content.ProductContent\x12\x35\n\x08material\x18\x05 \x01(\x0b\x32#.opencannabis.content.MaterialsData\x12<\n\x0bingredients\x18\x06 \x03(\x0b\x32\'.opencannabis.products.EdibleIngredient\"\xad\x01\n\x04Type\x12\x16\n\x12UNSPECIFIED_EDIBLE\x10\x00\x12\r\n\tCHOCOLATE\x10\x01\x12\x0e\n\nBAKED_GOOD\x10\x02\x12\t\n\x05\x43\x41NDY\x10\x03\x12\x0c\n\x08\x42\x45VERAGE\x10\x04\x12\x0b\n\x07LOZENGE\x10\x05\x12\x0e\n\nSUBLINGUAL\x10\x06\x12\t\n\x05GUMMY\x10\x07\x12\n\n\x06\x42UTTER\x10\x08\x12\x08\n\x04OILS\x10\t\x12\n\n\x06\x43\x45REAL\x10\n\x12\x0b\n\x07\x43\x41PSULE\x10\x0b\"n\n\x04\x46lag\x12\x12\n\x0eNO_EDIBLE_FLAG\x10\x00\x12\t\n\x05VEGAN\x10\x01\x12\x0f\n\x0bGLUTEN_FREE\x10\x02\x12\x0e\n\nSUGAR_FREE\x10\x03\x12\x0e\n\nFAIR_TRADE\x10\x04\x12\x0b\n\x07ORGANIC\x10\x05\x12\t\n\x05LOCAL\x10\x06\x42\x39\n\x1eio.opencannabis.schema.productB\rEdibleProductH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_content_dot_MaterialsData__pb2.DESCRIPTOR,opencannabis_dot_content_dot_ProductContent__pb2.DESCRIPTOR,])



_EDIBLE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencannabis.products.Edible.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_EDIBLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHOCOLATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAKED_GOOD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANDY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEVERAGE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOZENGE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUBLINGUAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GUMMY', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUTTER', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OILS', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CEREAL', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAPSULE', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=562,
  serialized_end=735,
)
_sym_db.RegisterEnumDescriptor(_EDIBLE_TYPE)

_EDIBLE_FLAG = _descriptor.EnumDescriptor(
  name='Flag',
  full_name='opencannabis.products.Edible.Flag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_EDIBLE_FLAG', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEGAN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLUTEN_FREE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUGAR_FREE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAIR_TRADE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORGANIC', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=737,
  serialized_end=847,
)
_sym_db.RegisterEnumDescriptor(_EDIBLE_FLAG)


_EDIBLEINGREDIENT = _descriptor.Descriptor(
  name='EdibleIngredient',
  full_name='opencannabis.products.EdibleIngredient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='opencannabis.products.EdibleIngredient.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='opencannabis.products.EdibleIngredient.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=231,
)


_EDIBLE = _descriptor.Descriptor(
  name='Edible',
  full_name='opencannabis.products.Edible',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.Edible.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.products.Edible.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='opencannabis.products.Edible.flags', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='opencannabis.products.Edible.product', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='material', full_name='opencannabis.products.Edible.material', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingredients', full_name='opencannabis.products.Edible.ingredients', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EDIBLE_TYPE,
    _EDIBLE_FLAG,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=234,
  serialized_end=847,
)

_EDIBLE.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_EDIBLE.fields_by_name['type'].enum_type = _EDIBLE_TYPE
_EDIBLE.fields_by_name['flags'].enum_type = _EDIBLE_FLAG
_EDIBLE.fields_by_name['product'].message_type = opencannabis_dot_content_dot_ProductContent__pb2._PRODUCTCONTENT
_EDIBLE.fields_by_name['material'].message_type = opencannabis_dot_content_dot_MaterialsData__pb2._MATERIALSDATA
_EDIBLE.fields_by_name['ingredients'].message_type = _EDIBLEINGREDIENT
_EDIBLE_TYPE.containing_type = _EDIBLE
_EDIBLE_FLAG.containing_type = _EDIBLE
DESCRIPTOR.message_types_by_name['EdibleIngredient'] = _EDIBLEINGREDIENT
DESCRIPTOR.message_types_by_name['Edible'] = _EDIBLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EdibleIngredient = _reflection.GeneratedProtocolMessageType('EdibleIngredient', (_message.Message,), {
  'DESCRIPTOR' : _EDIBLEINGREDIENT,
  '__module__' : 'opencannabis.products.Edible_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.EdibleIngredient)
  })
_sym_db.RegisterMessage(EdibleIngredient)

Edible = _reflection.GeneratedProtocolMessageType('Edible', (_message.Message,), {
  'DESCRIPTOR' : _EDIBLE,
  '__module__' : 'opencannabis.products.Edible_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.Edible)
  })
_sym_db.RegisterMessage(Edible)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/commerce/Currency.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/commerce/Currency.proto',
  package='opencannabis.commerce',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.currencyB\020CommerceCurrencyH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$opencannabis/commerce/Currency.proto\x12\x15opencannabis.commerce\"\xa0\x01\n\rCurrencyValue\x12\r\n\x05value\x18\x01 \x01(\x02\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32#.opencannabis.commerce.CurrencyType\x12\x33\n\x04\x66iat\x18\n \x01(\x0e\x32#.opencannabis.commerce.FiatCurrencyH\x00\x12\x10\n\x06\x63ustom\x18\x64 \x01(\tH\x00\x42\x06\n\x04spec*.\n\x0c\x43urrencyType\x12\x08\n\x04\x46IAT\x10\x00\x12\x08\n\x04REAL\x10\x01\x12\n\n\x06\x43RYPTO\x10\x02*)\n\x0c\x46iatCurrency\x12\x07\n\x03USD\x10\x00\x12\x07\n\x03\x43\x41\x44\x10\x01\x12\x07\n\x03\x45UR\x10\x02\x42=\n\x1fio.opencannabis.schema.currencyB\x10\x43ommerceCurrencyH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)

_CURRENCYTYPE = _descriptor.EnumDescriptor(
  name='CurrencyType',
  full_name='opencannabis.commerce.CurrencyType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FIAT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRYPTO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=226,
  serialized_end=272,
)
_sym_db.RegisterEnumDescriptor(_CURRENCYTYPE)

CurrencyType = enum_type_wrapper.EnumTypeWrapper(_CURRENCYTYPE)
_FIATCURRENCY = _descriptor.EnumDescriptor(
  name='FiatCurrency',
  full_name='opencannabis.commerce.FiatCurrency',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='USD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EUR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=274,
  serialized_end=315,
)
_sym_db.RegisterEnumDescriptor(_FIATCURRENCY)

FiatCurrency = enum_type_wrapper.EnumTypeWrapper(_FIATCURRENCY)
FIAT = 0
REAL = 1
CRYPTO = 2
USD = 0
CAD = 1
EUR = 2



_CURRENCYVALUE = _descriptor.Descriptor(
  name='CurrencyValue',
  full_name='opencannabis.commerce.CurrencyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='opencannabis.commerce.CurrencyValue.value', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.commerce.CurrencyValue.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fiat', full_name='opencannabis.commerce.CurrencyValue.fiat', index=2,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='opencannabis.commerce.CurrencyValue.custom', index=3,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.commerce.CurrencyValue.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=64,
  serialized_end=224,
)

_CURRENCYVALUE.fields_by_name['type'].enum_type = _CURRENCYTYPE
_CURRENCYVALUE.fields_by_name['fiat'].enum_type = _FIATCURRENCY
_CURRENCYVALUE.oneofs_by_name['spec'].fields.append(
  _CURRENCYVALUE.fields_by_name['fiat'])
_CURRENCYVALUE.fields_by_name['fiat'].containing_oneof = _CURRENCYVALUE.oneofs_by_name['spec']
_CURRENCYVALUE.oneofs_by_name['spec'].fields.append(
  _CURRENCYVALUE.fields_by_name['custom'])
_CURRENCYVALUE.fields_by_name['custom'].containing_oneof = _CURRENCYVALUE.oneofs_by_name['spec']
DESCRIPTOR.message_types_by_name['CurrencyValue'] = _CURRENCYVALUE
DESCRIPTOR.enum_types_by_name['CurrencyType'] = _CURRENCYTYPE
DESCRIPTOR.enum_types_by_name['FiatCurrency'] = _FIATCURRENCY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CurrencyValue = _reflection.GeneratedProtocolMessageType('CurrencyValue', (_message.Message,), {
  'DESCRIPTOR' : _CURRENCYVALUE,
  '__module__' : 'opencannabis.commerce.Currency_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.CurrencyValue)
  })
_sym_db.RegisterMessage(CurrencyValue)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/Merchandise.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.content import ProductContent_pb2 as opencannabis_dot_content_dot_ProductContent__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/Merchandise.proto',
  package='opencannabis.products',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.productB\022MerchandiseProductH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'opencannabis/products/Merchandise.proto\x12\x15opencannabis.products\x1a\"opencannabis/base/ProductKey.proto\x1a)opencannabis/content/ProductContent.proto\"\xff\x02\n\x0bMerchandise\x12*\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKey\x12\x35\n\x04type\x18\x02 \x01(\x0e\x32\'.opencannabis.products.Merchandise.Type\x12\x35\n\x05\x66lags\x18\x03 \x03(\x0e\x32&.opencannabis.products.MerchandiseFlag\x12\x35\n\x07product\x18\x04 \x01(\x0b\x32$.opencannabis.content.ProductContent\"\x9e\x01\n\x04Type\x12\x1b\n\x17UNSPECIFIED_MERCHANDISE\x10\x00\x12\x0c\n\x08\x43LOTHING\x10\x01\x12\r\n\tGLASSWARE\x10\x02\x12\r\n\tCONTAINER\x10\x03\x12\x0b\n\x07LIGHTER\x10\x04\x12\n\n\x06TSHIRT\x10\x05\x12\n\n\x06HOODIE\x10\x06\x12\x07\n\x03HAT\x10\x07\x12\x13\n\x0b\x41\x43\x43\x45SSORIES\x10\x08\x1a\x02\x08\x01\x12\n\n\x06PAPERS\x10\t*M\n\x0fMerchandiseFlag\x12\x18\n\x14NO_MERCHANDISE_FLAGS\x10\x00\x12\x10\n\x0cMEDICAL_ONLY\x10\x01\x12\x0e\n\nBRAND_SWAG\x10\x02\x42>\n\x1eio.opencannabis.schema.productB\x12MerchandiseProductH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_content_dot_ProductContent__pb2.DESCRIPTOR,])

_MERCHANDISEFLAG = _descriptor.EnumDescriptor(
  name='MerchandiseFlag',
  full_name='opencannabis.products.MerchandiseFlag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_MERCHANDISE_FLAGS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEDICAL_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAND_SWAG', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=531,
  serialized_end=608,
)
_sym_db.RegisterEnumDescriptor(_MERCHANDISEFLAG)

MerchandiseFlag = enum_type_wrapper.EnumTypeWrapper(_MERCHANDISEFLAG)
NO_MERCHANDISE_FLAGS = 0
MEDICAL_ONLY = 1
BRAND_SWAG = 2


_MERCHANDISE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencannabis.products.Merchandise.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_MERCHANDISE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLOTHING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLASSWARE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIGHTER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TSHIRT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOODIE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HAT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCESSORIES', index=8, number=8,
      serialized_options=b'\010\001',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAPERS', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=371,
  serialized_end=529,
)
_sym_db.RegisterEnumDescriptor(_MERCHANDISE_TYPE)


_MERCHANDISE = _descriptor.Descriptor(
  name='Merchandise',
  full_name='opencannabis.products.Merchandise',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.Merchandise.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.products.Merchandise.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='opencannabis.products.Merchandise.flags', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='opencannabis.products.Merchandise.product', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MERCHANDISE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=529,
)

_MERCHANDISE.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_MERCHANDISE.fields_by_name['type'].enum_type = _MERCHANDISE_TYPE
_MERCHANDISE.fields_by_name['flags'].enum_type = _MERCHANDISEFLAG
_MERCHANDISE.fields_by_name['product'].message_type = opencannabis_dot_content_dot_ProductContent__pb2._PRODUCTCONTENT
_MERCHANDISE_TYPE.containing_type = _MERCHANDISE
DESCRIPTOR.message_types_by_name['Merchandise'] = _MERCHANDISE
DESCRIPTOR.enum_types_by_name['MerchandiseFlag'] = _MERCHANDISEFLAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Merchandise = _reflection.GeneratedProtocolMessageType('Merchandise', (_message.Message,), {
  'DESCRIPTOR' : _MERCHANDISE,
  '__module__' : 'opencannabis.products.Merchandise_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.Merchandise)
  })
_sym_db.RegisterMessage(Merchandise)


DESCRIPTOR._options = None
_MERCHANDISE_TYPE.values_by_name["ACCESSORIES"]._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/temporal/Time.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/temporal/Time.proto',
  package='opencannabis.temporal',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.temporalB\014TemporalTimeH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n opencannabis/temporal/Time.proto\x12\x15opencannabis.temporal\"!\n\x04Time\x12\x11\n\x07iso8601\x18\x01 \x01(\tH\x00\x42\x06\n\x04specB9\n\x1fio.opencannabis.schema.temporalB\x0cTemporalTimeH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)




_TIME = _descriptor.Descriptor(
  name='Time',
  full_name='opencannabis.temporal.Time',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='iso8601', full_name='opencannabis.temporal.Time.iso8601', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.temporal.Time.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=59,
  serialized_end=92,
)

_TIME.oneofs_by_name['spec'].fields.append(
  _TIME.fields_by_name['iso8601'])
_TIME.fields_by_name['iso8601'].containing_oneof = _TIME.oneofs_by_name['spec']
DESCRIPTOR.message_types_by_name['Time'] = _TIME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Time = _reflection.GeneratedProtocolMessageType('Time', (_message.Message,), {
  'DESCRIPTOR' : _TIME,
  '__module__' : 'opencannabis.temporal.Time_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.temporal.Time)
  })
_sym_db.RegisterMessage(Time)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/temporal/Duration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/temporal/Duration.proto',
  package='opencannabis.temporal',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.temporalH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$opencannabis/temporal/Duration.proto\x12\x15opencannabis.temporal\x1a\x19gust/core/datamodel.proto\"I\n\x08\x44uration\x12-\n\x04unit\x18\x01 \x01(\x0e\x32\x1f.opencannabis.temporal.TimeUnit\x12\x0e\n\x06\x61mount\x18\x02 \x01(\r*\x7f\n\x08TimeUnit\x12\x10\n\x0cMILLISECONDS\x10\x00\x12\x10\n\x0cMICROSECONDS\x10\x01\x12\x0b\n\x07SECONDS\x10\x02\x12\x0b\n\x07MINUTES\x10\x03\x12\t\n\x05HOURS\x10\x04\x12\x08\n\x04\x44\x41YS\x10\x05\x12\t\n\x05WEEKS\x10\x06\x12\n\n\x06MONTHS\x10\x07\x12\t\n\x05YEARS\x10\x08\x42+\n\x1fio.opencannabis.schema.temporalH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])

_TIMEUNIT = _descriptor.EnumDescriptor(
  name='TimeUnit',
  full_name='opencannabis.temporal.TimeUnit',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MILLISECONDS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MICROSECONDS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECONDS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MINUTES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOURS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAYS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEEKS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONTHS', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YEARS', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=165,
  serialized_end=292,
)
_sym_db.RegisterEnumDescriptor(_TIMEUNIT)

TimeUnit = enum_type_wrapper.EnumTypeWrapper(_TIMEUNIT)
MILLISECONDS = 0
MICROSECONDS = 1
SECONDS = 2
MINUTES = 3
HOURS = 4
DAYS = 5
WEEKS = 6
MONTHS = 7
YEARS = 8



_DURATION = _descriptor.Descriptor(
  name='Duration',
  full_name='opencannabis.temporal.Duration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit', full_name='opencannabis.temporal.Duration.unit', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='opencannabis.temporal.Duration.amount', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=163,
)

_DURATION.fields_by_name['unit'].enum_type = _TIMEUNIT
DESCRIPTOR.message_types_by_name['Duration'] = _DURATION
DESCRIPTOR.enum_types_by_name['TimeUnit'] = _TIMEUNIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Duration = _reflection.GeneratedProtocolMessageType('Duration', (_message.Message,), {
  'DESCRIPTOR' : _DURATION,
  '__module__' : 'opencannabis.temporal.Duration_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.temporal.Duration)
  })
_sym_db.RegisterMessage(Duration)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/geo/Location.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.geo import Point_pb2 as opencannabis_dot_geo_dot_Point__pb2
from opencannabis.geo import Address_pb2 as opencannabis_dot_geo_dot_Address__pb2
from opencannabis.geo import Distance_pb2 as opencannabis_dot_geo_dot_Distance__pb2
from opencannabis.content import Name_pb2 as opencannabis_dot_content_dot_Name__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/geo/Location.proto',
  package='opencannabis.geo',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.geoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/geo/Location.proto\x12\x10opencannabis.geo\x1a\x19gust/core/datamodel.proto\x1a\x1copencannabis/geo/Point.proto\x1a\x1eopencannabis/geo/Address.proto\x1a\x1fopencannabis/geo/Distance.proto\x1a\x1fopencannabis/content/Name.proto\"\x87\x03\n\x08Location\x12V\n\x04name\x18\x01 \x01(\x0b\x32\x1a.opencannabis.content.NameB,\xc2\xb5\x03(\x12&Name for this location, if applicable.\x12[\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x19.opencannabis.geo.AddressB/\xc2\xb5\x03+\x12)Address for this location, if applicable.\x12^\n\x05point\x18\x03 \x01(\x0b\x32\x17.opencannabis.geo.PointB6\xc2\xb5\x03\x32\x12\x30Geopoint (latitude/longitude) for this location.\x12\x66\n\x08\x61\x63\x63uracy\x18\x04 \x01(\x0b\x32\".opencannabis.geo.LocationAccuracyB0\xc2\xb5\x03,\x12*Specifies the accuracy estimate, if known.B&\n\x1aio.opencannabis.schema.geoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_geo_dot_Point__pb2.DESCRIPTOR,opencannabis_dot_geo_dot_Address__pb2.DESCRIPTOR,opencannabis_dot_geo_dot_Distance__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Name__pb2.DESCRIPTOR,])




_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='opencannabis.geo.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.geo.Location.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003(\022&Name for this location, if applicable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='opencannabis.geo.Location.address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003+\022)Address for this location, if applicable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point', full_name='opencannabis.geo.Location.point', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0032\0220Geopoint (latitude/longitude) for this location.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='opencannabis.geo.Location.accuracy', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003,\022*Specifies the accuracy estimate, if known.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=600,
)

_LOCATION.fields_by_name['name'].message_type = opencannabis_dot_content_dot_Name__pb2._NAME
_LOCATION.fields_by_name['address'].message_type = opencannabis_dot_geo_dot_Address__pb2._ADDRESS
_LOCATION.fields_by_name['point'].message_type = opencannabis_dot_geo_dot_Point__pb2._POINT
_LOCATION.fields_by_name['accuracy'].message_type = opencannabis_dot_geo_dot_Distance__pb2._LOCATIONACCURACY
DESCRIPTOR.message_types_by_name['Location'] = _LOCATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
  'DESCRIPTOR' : _LOCATION,
  '__module__' : 'opencannabis.geo.Location_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.Location)
  })
_sym_db.RegisterMessage(Location)


DESCRIPTOR._options = None
_LOCATION.fields_by_name['name']._options = None
_LOCATION.fields_by_name['address']._options = None
_LOCATION.fields_by_name['point']._options = None
_LOCATION.fields_by_name['accuracy']._options = None
# @@protoc_insertion_point(module_scope)
